@@ -15,7 +15,7 @@
     Boston, MA  02110-1301, USA.
 
     ---
-    Copyright (C) 2020-2022 Alexander Semke <alexander.semke@web.de>
+    Copyright (C) 2020-2023 Alexander Semke <alexander.semke@web.de>
  */
 
 #include "juliasettingswidget.h"
@@ -26,8 +26,6 @@ JuliaSettingsWidget::JuliaSettingsWidget(QWidget* parent, const QString& id) : B
 
     m_tabWidget = tabWidget;
     m_tabDocumentation = tabDocumentation;
-    m_urlRequester = kcfg_replPath;
 
     connect(tabWidget, &QTabWidget::currentChanged, this, &BackendSettingsWidget::tabChanged);
-    connect(kcfg_replPath, &KUrlRequester::textChanged, this, &BackendSettingsWidget::fileNameChanged);
 }
