@@ -1,47 +1,27 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2012 Martin Kuettler <martin.kuettler@gmail.com>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2012 Martin Kuettler <martin.kuettler@gmail.com>
+*/
 
 #include "searchbar.h"
 
 #include "worksheet.h"
 #include "worksheetentry.h"
 #include "worksheettextitem.h"
+#include "worksheetview.h"
 
 #include <KLocalizedString>
 #include <QIcon>
 #include <QMenu>
-#include <QDebug>
 
-SearchBar::SearchBar(QWidget* parent, Worksheet* worksheet) : QWidget(parent)
+SearchBar::SearchBar(QWidget* parent, Worksheet* worksheet) : QWidget(parent),
+    m_stdUi(new Ui::StandardSearchBar()),
+    m_worksheet(worksheet),
+    m_searchFlags{WorksheetEntry::SearchAll}
 {
-    m_worksheet = worksheet;
-    m_stdUi = new Ui::StandardSearchBar();
-    m_extUi = nullptr;
     setupStdUi();
-    m_qtFlags = {};
     setStartCursor(worksheet->worksheetCursor());
     setCurrentCursor(m_startCursor);
-    m_atBeginning = false;
-    m_atEnd = false;
-    m_notFound = false;
-    m_searchFlags = WorksheetEntry::SearchAll;
 }
 
 SearchBar::~SearchBar()
@@ -66,9 +46,9 @@ void SearchBar::showStandard()
 
     delete m_extUi;
     m_extUi = nullptr;
-    foreach(QObject* child, children()) {
+    for (auto* child : children())
         delete child;
-    }
+
     delete layout();
     m_stdUi = new Ui::StandardSearchBar();
     setupStdUi();
@@ -81,9 +61,9 @@ void SearchBar::showExtended()
 
     delete m_stdUi;
     m_stdUi = nullptr;
-    foreach(QObject* child, children()) {
+    for (auto* child : children())
         delete child;
-    }
+
     delete layout();
     m_extUi = new Ui::ExtendedSearchBar();
     setupExtUi();
@@ -165,7 +145,6 @@ void SearchBar::searchForward(bool skipFirstChar)
         if (skipFirstChar) {
             QTextCursor c = m_currentCursor.textCursor();
             c.movePosition(QTextCursor::NextCharacter);
-            qDebug() << c.position();
             setCurrentCursor(WorksheetCursor(m_currentCursor.entry(),
                                              m_currentCursor.textItem(), c));
         }
@@ -498,5 +477,3 @@ Worksheet* SearchBar::worksheet()
 {
     return m_worksheet;
 }
-
-
